/*
 * version.h
 *
 * Written by
 *  Andreas Boose <viceteam@t-online.de>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef VICE__VERSION_H__
#define VICE__VERSION_H__

#ifndef VICE_VERSION_MAJOR
#define VICE_VERSION_MAJOR 3
#endif

#ifndef VICE_VERSION_MINOR
#define VICE_VERSION_MINOR 10
#endif

#ifndef VICE_VERSION_BUILD
#define VICE_VERSION_BUILD 0
#endif

#ifndef VERSION
#define VERSION "3.10"
#endif

#ifndef VERSION_WITH_BUILD
#define VERSION_WITH_BUILD "3.10.0"
#endif

#ifndef VERSION_RC_NUMBER
#define VERSION_RC_NUMBER 3,10,0,0
#endif

#ifndef PACKAGE
#define PACKAGE "vice"
#endif



#endif
